# openldap upon which we have optional dependencies
%bcond_with openldap
# initscripts upon which we have optional dependencies
%bcond_with initscripts
# for controlling python bindings
%bcond_with python

%define python_version %(%{__python} -c "from sys import version; print version[:3]")
%define PYVER %{python_version}
%define PYLIBVER python%{python_version}
%define SWIG_HOST_VER 1.3.31
# openldap upon which we have optional dependencies
%bcond_with openldap
# initscripts upon which we have optional dependencies
%bcond_with initscripts

%define python_version %(%{__python} -c "from sys import version; print version[:3]")
%define PYVER %{python_version}
%define PYLIBVER python%{python_version}
%define SWIG_HOST_VER 1.3.31

%{!?python_sitearch: %define python_sitearch %(%{__python} -c "from distutils.sysconfig import get_python_lib; print get_python_lib(1)")}

Summary: User space tools for 2.6 kernel auditing
Name: audit
Version: 2.0.5
Release: 1_WR%{?_ldat_rel}
License: GPL-2.0
Group: System Environment/Daemons
URL: http://people.redhat.com/sgrubb/audit/
Source0: http://people.redhat.com/sgrubb/audit/%{name}-%{version}.tar.gz

# WRLinux patches
Patch500: auditd.conf.patch
Patch501: audit-swig.patch
Patch502: audit-etc-install.patch
Patch504: audit-python-cross-compile.patch
Patch505: audit-cross-compile.patch
Patch506: audit-limits.patch
Patch507: audit-fcntl-include-fixes.patch
Patch508: audit-without-openldap.patch
Patch509: audit-install.patch
Patch510: no-python.patch
Patch511: audit-mips-all-subarch.patch

BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root
BuildRequires: swig python-devel
BuildRequires: tcp-wrappers-devel
BuildRequires: kernel-headers
Requires: %{name}-libs = %{version}-%{release}
# WRLinux add initscripts if present
%if %{with initscripts}
Requires: initscripts
%endif

%description
The audit package contains the user space utilities for
storing and searching the audit records generate by
the audit subsystem in the Linux 2.6 kernel.

%package libs
Summary: Dynamic library for libaudit
License: LGPL-2.1
Group: Development/Libraries

%description libs
The audit-libs package contains the dynamic libraries needed for 
applications to use the audit framework.

%package libs-devel
Summary: Header files and static library for libaudit
License: LGPL-2.1
Group: Development/Libraries
Requires: %{name}-libs = %{version}-%{release}
Requires: kernel-headers

%description libs-devel
The audit-libs-devel package contains the static libraries and header 
files needed for developing applications that need to use the audit 
framework libraries.

%if %{with python}
%package libs-python
Summary: Python bindings for libaudit
License: LGPL-2.1
Group: Development/Libraries
Requires: %{name}-libs = %{version}-%{release}

%description libs-python
The audit-libs-python package contains the bindings so that libaudit
and libauparse can be used by python.
%endif

%if %{with openldap}
%package -n audispd-plugins
Summary: Plugins for the audit event dispatcher
License: GPL-2.0
Group: System Environment/Daemons
BuildRequires: openldap-devel
Requires: %{name} = %{version}-%{release}
Requires: %{name}-libs = %{version}-%{release}
Requires: openldap

%description -n audispd-plugins
The audispd-plugins package provides plugins for the real-time
interface to the audit system, audispd. These plugins can do things
like relay events to remote machines or analyze events for suspicious
behavior.
%endif

%prep
%setup -q

# WRLinux patching
%patch500 -p1
%patch501 -p1
%patch502 -p1
%patch504 -p1
%patch505 -p1 -b .cross_compile
%patch506 -p1 -b .b4_limits
%patch507 -p1
%if %{with openldap}
%patch509 -p1
%else
%patch508 -p1
%endif
%if %{without python}
%patch510 -p1 .no-python
%endif
%patch511 -p1

autoreconf --force --install

%build

# Without openldap package, '/sbin/audispd' in the auditd.conf file should be removed.
%if %{without openldap}
sed '/audispd/d' -i init.d/auditd.conf
%endif

# WRLinux: add WORDSIZE if build for mips __WORDSIZE = _MIPS_SZPTR
%if_arch mips
_MIPS_SZPTR=`${CC}  -dM -E - < /dev/null | egrep _MIPS_SZPTR | cut -d' ' -f3`
CFLAGS="${CFLAGS} -D_MIPS_SZPTR=${_MIPS_SZPTR}"; export CFLAGS
TARGET_MIPS_SZPTR="-D_MIPS_SZPTR=${_MIPS_SZPTR}"
%endif

%configure --sbindir=/sbin --libdir=/%{_lib} LD="%{__ld}" --without-prelude \
  --with-libwrap --enable-gssapi-krb5=no --with-libcap-ng=no

# some executable objects in host environment are needed to create header files.
mkdir -p lib/linux
cp -f %{_host_cross_include_dir}/linux/audit.h lib/linux
cp -f %{_host_cross_include_dir}/linux/elf-em.h lib/linux
make -C lib host_gen CC=%{_host_cc} CFLAGS="%{_host_cflags} ${TARGET_MIPS_SZPTR}"
make -C auparse host_gen CC=%{_host_cc} CFLAGS="%{_host_cflags} ${TARGET_MIPS_SZPTR}"

make \
SWIGINC="%{_host_build_lib_dir}/../share/swig/%{SWIG_HOST_VER}" \
SWIGPYINC="%{_host_build_lib_dir}/../share/swig/%{SWIG_HOST_VER}/python" \
PYINC="%{_host_cross_include_dir}/%{PYLIBVER}" \
%{?_smp_mflags}

%install
# wrs macro that exports standard build variables to environment
%configure_target

rm -rf $RPM_BUILD_ROOT
%if %{with openldap}
mkdir -p $RPM_BUILD_ROOT/{sbin,etc/{sysconfig,audispd/plugins.d,rc.d/init.d}}
%endif
mkdir -p $RPM_BUILD_ROOT/%{_mandir}/{man5,man8}
mkdir -p $RPM_BUILD_ROOT/%{_lib}
mkdir -p $RPM_BUILD_ROOT/%{_libdir}/audit
mkdir -p $RPM_BUILD_ROOT/%{_var}/log/audit
make DESTDIR=$RPM_BUILD_ROOT pyexecdir=%{_libdir}/python%{PYVER}/site-packages pythondir=%{_libdir}/python%{PYVER}/site-packages DATADIRNAME=share install

# WRLinux if initscript is not present then remove it
%if %{with initscripts}
# keep /etc/rc.d/init.d/auditd
%else
rm -rf $RPM_BUILD_ROOT/etc/rc.d
%endif

mkdir -p $RPM_BUILD_ROOT/%{_libdir}
# This winds up in the wrong place when libtool is involved
mv $RPM_BUILD_ROOT/%{_lib}/libaudit.a $RPM_BUILD_ROOT%{_libdir}
mv $RPM_BUILD_ROOT/%{_lib}/libauparse.a $RPM_BUILD_ROOT%{_libdir}
curdir=`pwd`
cd $RPM_BUILD_ROOT/%{_libdir}
LIBNAME=`basename \`ls $RPM_BUILD_ROOT/%{_lib}/libaudit.so.1.*.*\``
ln -s ../../%{_lib}/$LIBNAME libaudit.so
LIBNAME=`basename \`ls $RPM_BUILD_ROOT/%{_lib}/libauparse.so.0.*.*\``
ln -s ../../%{_lib}/$LIBNAME libauparse.so
cd $curdir
# Remove these items so they don't get picked up.
rm -f $RPM_BUILD_ROOT/%{_lib}/libaudit.so
rm -f $RPM_BUILD_ROOT/%{_lib}/libauparse.so
rm -f $RPM_BUILD_ROOT/%{_lib}/libaudit.la
rm -f $RPM_BUILD_ROOT/%{_lib}/libauparse.la
rm -f $RPM_BUILD_ROOT/%{_libdir}/python%{PYVER}/site-packages/_audit.a
rm -f $RPM_BUILD_ROOT/%{_libdir}/python%{PYVER}/site-packages/_audit.la
rm -f $RPM_BUILD_ROOT/%{_libdir}/python%{PYVER}/site-packages/_auparse.a
rm -f $RPM_BUILD_ROOT/%{_libdir}/python%{PYVER}/site-packages/_auparse.la
rm -f $RPM_BUILD_ROOT/%{_libdir}/python%{PYVER}/site-packages/auparse.a
rm -f $RPM_BUILD_ROOT/%{_libdir}/python%{PYVER}/site-packages/auparse.la

# On platforms with 32 & 64 bit libs, we need to coordinate the timestamp
touch -r ./audit.spec $RPM_BUILD_ROOT/etc/libaudit.conf
touch -r ./audit.spec $RPM_BUILD_ROOT/usr/share/man/man5/libaudit.conf.5.gz

%check
make check

%if 0
# wrs does not use these build rules
%clean
rm -rf $RPM_BUILD_ROOT

%post libs -p /sbin/ldconfig

%post
/sbin/chkconfig --add auditd

%preun
if [ $1 -eq 0 ]; then
   /sbin/service auditd stop > /dev/null 2>&1
   /sbin/chkconfig --del auditd
fi

%postun libs -p /sbin/ldconfig

%postun
if [ $1 -ge 1 ]; then
   /sbin/service auditd condrestart > /dev/null 2>&1 || :
fi
%endif

%if %{with initscripts}
%wrs_post -p <lua>
wrs.chkconfig('--add auditd')

%wrs_preun -p <lua>
wrs.chkconfig('--del auditd')
%endif

%files libs
%defattr(-,root,root,-)
%attr(755,root,root) /%{_lib}/libaudit.so.1*
%attr(755,root,root) /%{_lib}/libauparse.*
%config(noreplace) %attr(640,root,root) /etc/libaudit.conf
%{_mandir}/man5/libaudit.conf.5.gz

%files libs-devel
%defattr(-,root,root,-)
%doc contrib/skeleton.c contrib/plugin
%{_libdir}/libaudit.a
%{_libdir}/libauparse.a
%{_libdir}/libaudit.so
%{_libdir}/libauparse.so
%{_includedir}/libaudit.h
%{_includedir}/auparse.h
%{_includedir}/auparse-defs.h
%{_mandir}/man3/*

%if %{with python}
%files libs-python
%defattr(-,root,root,-)
%attr(755,root,root) %{_libdir}/python%{PYVER}/site-packages/_audit.so
%attr(755,root,root) %{_libdir}/python%{PYVER}/site-packages/auparse.so
%{_libdir}/python%{PYVER}/site-packages/audit.py*
%endif

%files
%defattr(-,root,root,-)
%doc  README COPYING ChangeLog contrib/capp.rules contrib/nispom.rules contrib/lspp.rules contrib/stig.rules
%if %{with initscripts}
%doc init.d/auditd.cron
%attr(755,root,root) /etc/rc.d/init.d/auditd
%endif
%attr(644,root,root) %{_mandir}/man8/audispd.8.gz
%attr(644,root,root) %{_mandir}/man8/auditctl.8.gz
%attr(644,root,root) %{_mandir}/man8/auditd.8.gz
%attr(644,root,root) %{_mandir}/man8/aureport.8.gz
%attr(644,root,root) %{_mandir}/man8/ausearch.8.gz
%attr(644,root,root) %{_mandir}/man8/autrace.8.gz
%attr(644,root,root) %{_mandir}/man8/aulast.8.gz
%attr(644,root,root) %{_mandir}/man8/aulastlog.8.gz
%attr(644,root,root) %{_mandir}/man8/ausyscall.8.gz
%attr(644,root,root) %{_mandir}/man7/audit.rules.7.gz
%attr(644,root,root) %{_mandir}/man5/auditd.conf.5.gz
%attr(644,root,root) %{_mandir}/man5/audispd.conf.5.gz
%attr(644,root,root) %{_mandir}/man5/ausearch-expression.5.gz
%attr(750,root,root) /sbin/auditctl
%attr(750,root,root) /sbin/auditd
%attr(755,root,root) /sbin/ausearch
%attr(755,root,root) /sbin/aureport
%attr(750,root,root) /sbin/autrace
%if %{with openldap}
%attr(750,root,root) /sbin/audispd
%endif
%attr(755,root,root) %{_bindir}/aulast
%attr(755,root,root) %{_bindir}/aulastlog
%attr(755,root,root) %{_bindir}/ausyscall
%attr(750,root,root) %{_var}/log/audit
%attr(750,root,root) %dir /etc/audit
%attr(750,root,root) %dir /etc/audisp
%if %{with openldap}
%attr(750,root,root) %dir /etc/audisp/plugins.d
%endif
%attr(750,root,root) %dir %{_libdir}/audit
%config(noreplace) %attr(640,root,root) /etc/audit/auditd.conf
%config(noreplace) %attr(640,root,root) /etc/audit/audit.rules
%config(noreplace) %attr(640,root,root) /etc/sysconfig/auditd
%if %{with openldap}
%config(noreplace) %attr(640,root,root) /etc/audisp/audispd.conf
%config(noreplace) %attr(640,root,root) /etc/audisp/plugins.d/af_unix.conf
%config(noreplace) %attr(640,root,root) /etc/audisp/plugins.d/syslog.conf

%files -n audispd-plugins
%defattr(-,root,root,-)
%attr(644,root,root) %{_mandir}/man8/audispd-zos-remote.8.gz
%attr(644,root,root) %{_mandir}/man5/zos-remote.conf.5.gz
%config(noreplace) %attr(640,root,root) /etc/audisp/plugins.d/audispd-zos-remote.conf
%config(noreplace) %attr(640,root,root) /etc/audisp/zos-remote.conf
%attr(750,root,root) /sbin/audispd-zos-remote
%config(noreplace) %attr(640,root,root) /etc/audisp/audisp-remote.conf
%config(noreplace) %attr(640,root,root) /etc/audisp/plugins.d/au-remote.conf
%attr(750,root,root) /sbin/audisp-remote
%attr(644,root,root) %{_mandir}/man5/audisp-remote.conf.5.gz
%attr(644,root,root) %{_mandir}/man8/audisp-remote.8.gz
%endif


%changelog
* Wed Sep 22 2010 Steve Grubb <sgrubb@redhat.com> 2.0.5-1
- New upstream release

